package main

import (
	"html/template"
	"log"
	"net/http"

	"streifling.com/jason/sicherheitsunterweisung/packages/data"
	"streifling.com/jason/sicherheitsunterweisung/packages/session"
)

func main() {
	db, err := data.OpenDB("sicherheitsunterweisung")
	if err != nil {
		log.Fatalln(err)
	}

	mux := session.NewMux()
	sessions := make([]*session.Session, 0)
	sessionChan := make(chan *session.Session)

	mux.Handle("/static/", http.StripPrefix("/static/", http.FileServer(http.Dir("static/"))))
	mux.HandleFunc("/", func(w http.ResponseWriter, r *http.Request) {
		template.Must(template.ParseFiles("templates/index.html", "templates/login.html")).Execute(w, nil)
	})
	mux.HandleFunc("/internal-login/", session.HandleInternalLogin(db, &sessions, sessionChan))
	mux.HandleFunc("/external-login/", session.HandleExternalLogin(&sessions))

	go mux.HandleSessions(db, sessionChan, &sessions)

	log.Fatalln(http.ListenAndServe(":8080", mux))
}
